@@ -1,6 +1,8 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 from .fpn import FPN
+from .ic_neck import ICNeck
+from .jpu import JPU
 from .mla_neck import MLANeck
 from .multilevel_neck import MultiLevelNeck
 
-__all__ = ['FPN', 'MultiLevelNeck', 'MLANeck']
+__all__ = ['FPN', 'MultiLevelNeck', 'MLANeck', 'ICNeck', 'JPU']
